summaryrefslogtreecommitdiff
path: root/src/station_gui.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/station_gui.cpp')
-rw-r--r--src/station_gui.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/station_gui.cpp b/src/station_gui.cpp
index 62d3d642d..94b7afc01 100644
--- a/src/station_gui.cpp
+++ b/src/station_gui.cpp
@@ -952,16 +952,16 @@ struct StationViewWindow : public Window {
case SVW_PLANES: { // Show a list of scheduled aircraft to this station
const Station *st = GetStation(this->window_number);
- /* Since oilrigs have no owners, show the scheduled aircraft of current company */
- Owner owner = (st->owner == OWNER_NONE) ? _current_company : st->owner;
+ /* Since oilrigs have no owners, show the scheduled aircraft of local company */
+ Owner owner = (st->owner == OWNER_NONE) ? _local_company : st->owner;
ShowVehicleListWindow(owner, VEH_AIRCRAFT, (StationID)this->window_number);
break;
}
case SVW_SHIPS: { // Show a list of scheduled ships to this station
const Station *st = GetStation(this->window_number);
- /* Since oilrigs/bouys have no owners, show the scheduled ships of current company */
- Owner owner = (st->owner == OWNER_NONE) ? _current_company : st->owner;
+ /* Since oilrigs/bouys have no owners, show the scheduled ships of local company */
+ Owner owner = (st->owner == OWNER_NONE) ? _local_company : st->owner;
ShowVehicleListWindow(owner, VEH_SHIP, (StationID)this->window_number);
break;
}